import { Injectable } from '@angular/core';
import { AngularFireAuth } from '@angular/fire/auth';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  authUser: any;

  constructor(private afAuth: AngularFireAuth) {
    this.checkLocalStorage();
  }

  get authenticated(): boolean {
    return !!this.authUser;
  }

  get currentUser(): any {
    return this.authenticated ? this.authUser : null;
  }

  signIn(email: string, password: string, onSuccess: () => void, onError: (err: string) => void) {
    return this.afAuth.signInWithEmailAndPassword(email, password)
      .then(data => {
        this.authUser = data.user;
        onSuccess();
      })
      .catch(err => {
        onError(err);
      });
  }

  signOut(onSuccess: () => void, onError?: (err: string) => void) {
    this.afAuth.signOut()
      .then(() => {
        this.authUser = null;
        localStorage.removeItem('env-monitor-user');
        onSuccess();
      })
      .catch(err => {
        onError(err);
      });
  }

  resetPasswordEmail(email: string, onSuccess: () => void, onError: (err: string) => void) {
    return this.afAuth.sendPasswordResetEmail(email)
      .then(() => {
        onSuccess();
      })
      .catch(err => {
        onError(err);
      });
  }

  private checkLocalStorage() {
    if (localStorage.getItem('env-monitor-user')) {
      this.authUser = JSON.parse(localStorage.getItem('env-monitor-user'));
    }
    else {
      this.afAuth.authState.subscribe(auth => {
        this.authUser = auth;
        localStorage.setItem('env-monitor-user', JSON.stringify(auth));
      });
    }
  }

}
